data 'DLOG' (1130) {
	$"0028 0014 0104 0104 0001 0100 0100 0000"            /* .(.............. */
	$"0000 046A 0743 6F6E 6669 726D 300A"                 /* ...j.Confirm0. */
};

data 'DLOG' (1131) {
	$"0058 003E 0120 012E 0001 0100 0000 0000"            /* .X.>. .......... */
	$"0000 046B 0752 6571 7565 7374 300A"                 /* ...k.Request0. */
};

data 'DLOG' (1132, purgeable) {
	$"0000 0000 00CD 0158 0001 0000 0000 0000"            /* ......X........ */
	$"0000 046C 0000 0000"                                /* ...l.... */
};

data 'DITL' (130, "Error") {
	$"0001 0000 0000 0085 00BE 009D 00FE 0402"            /* ............ */
	$"4F4B 0000 0000 0004 0005 007C 0114 0808"            /* OK.........|.... */
	$"5E30 5E31 5E32 5E33"                                /* ^0^1^2^3 */
};

data 'DITL' (1129, purgeable) {
	$"0002 0000 0000 00AA 0096 00BE 00E6 0402"            /* ............ */
	$"4F4B 0000 0000 000A 003C 00A0 00E6 8802"            /* OK.......<... */
	$"5E30 0000 0000 0008 0008 0028 0028 A002"            /* ^0.........(.(. */
	$"0002"                                               /* .. */
};

data 'DITL' (1130, purgeable) {
	$"0004 0000 0000 00AA 0096 00BE 00E6 0403"            /* ............ */
	$"5965 7300 0000 0000 00AA 0032 00BE 0082"            /* Yes.......2.. */
	$"0402 4E6F 0000 0000 000A 003C 00A0 00E6"            /* ..No.......<.. */
	$"8802 5E30 0000 0000 0008 0008 0028 0028"            /* .^0.........(.( */
	$"A002 0002 0000 0000 00AA 000A 00BE 001E"            /* ............. */
	$"8000"                                               /* . */
};

data 'DITL' (1131) {
	$"0004 0000 0000 0096 00A0 00AA 00DA 0402"            /* ............ */
	$"4F4B 0000 0000 0096 005A 00AA 0094 0406"            /* OK......Z.... */
	$"4361 6E63 656C 0000 0000 003C 0014 0085"            /* Cancel.....<... */
	$"00D9 9010 7365 7276 6572 4068 6F73 742E"            /* .ِ.server@host. */
	$"7A6F 6E65 0000 0000 000A 0014 0031 00D8"            /* zone.........1. */
	$"8802 5E30 0000 0000 0096 001E 00AA 0032"            /* .^0.........2 */
	$"8000"                                               /* . */
};

data 'DITL' (1132, purgeable) {
	$"000A 0000 0000 00AB 00FC 00BF 014C 0406"            /* ..........L.. */
	$"4C61 756E 6368 0000 0000 008C 00FC 00A0"            /* Launch....... */
	$"014C 0406 4361 6E63 656C 0000 0000 0000"            /* .L..Cancel...... */
	$"0000 0000 0000 8104 0001 046C 0000 0000"            /* ..........l.... */
	$"002C 00EB 003C 0151 0000 0000 0000 0044"            /* .,..<.Q.......D */
	$"00FC 0058 014C 0405 456A 6563 7400 0000"            /* ..X.L..Eject... */
	$"0000 0060 00FC 0074 014C 0407 4465 736B"            /* ...`..t.L..Desk */
	$"746F 7000 0000 0000 0041 000C 00C3 00E6"            /* top......A.... */
	$"0000 0000 0000 002A 000C 003D 00E6 0000"            /* .......*...=... */
	$"0000 0000 007F 00FB 0080 014D C002 000B"            /* .........M... */
	$"0000 0000 000A 000D 001C 0152 8824 4368"            /* ..........R$Ch */
	$"6F6F 7365 2061 204D 6174 684C 696E 6B20"            /* oose a MathLink  */
	$"7072 6F67 7261 6D20 746F 206C 6175 6E63"            /* program to launc */
	$"683A 0000 0000 00CD 000A 00DF 0108 0520"            /* h:...........  */
	$"4C69 7374 2061 7661 696C 6162 6C65 204D"            /* List available M */
	$"6174 684C 696E 6B20 7072 6F67 7261 6D73"            /* athLink programs */
};

data 'ICN#' (128) {
	$"0000 0000 0000 0000 01FF FF80 0200 0040"            /* ............@ */
	$"0400 0020 0800 0010 1000 0008 1000 0008"            /* ... ............ */
	$"21E0 0784 21E0 0784 41E0 0782 41E0 0782"            /* !.!.A.A. */
	$"81E0 0781 81E0 0781 81E0 0781 81E0 0781"            /* .... */
	$"81E0 0781 81E0 0781 81E0 0001 8000 0001"            /* ....... */
	$"4001 8002 4003 C002 2007 E004 2007 E004"            /* @..@.. .. .. */
	$"1007 E008 1007 E008 0800 0010 0400 0020"            /* .............  */
	$"0200 0040 01FF FF80 0000 0000 0000 0000"            /* ...@......... */
	$"0000 0000 0000 0000 01FF FF80 03FF FFC0"            /* .......... */
	$"07FF FFE0 0FFF FFF0 1FFF FFF8 1FFF FFF8"            /* .... */
	$"3FFF FFFC 3FFF FFFC 7FFF FFFE 7FFF FFFE"            /* ??.. */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /*  */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /*  */
	$"7FFF FFFE 7FFF FFFE 3FFF FFFC 3FFF FFFC"            /* ..?? */
	$"1FFF FFF8 1FFF FFF8 0FFF FFF0 07FF FFE0"            /* .... */
	$"03FF FFC0 01FF FF80 0000 0000 0000 0000"            /* .......... */
};

data 'ICN#' (129) {
	$"0FFF FE00 0800 3300 0800 6280 0800 6240"            /* ....3...b..b@ */
	$"0800 6220 0800 3210 0800 1BF8 0800 1808"            /* ..b ..2........ */
	$"0800 0C08 0800 0608 0800 0608 0800 0308"            /* ................ */
	$"0800 0188 0800 0188 0800 00C8 0818 00C8"            /* ............ */
	$"081C 00C8 081E 00C8 0BFE 0388 0BFF 1F08"            /* ........... */
	$"081F FC08 081F E008 0BFF 0008 0BFE 0008"            /* ............ */
	$"081E 0008 081C 0008 0818 0008 0800 0008"            /* ................ */
	$"0800 0008 0800 0008 0800 0008 0FFF FFF8"            /* ............. */
	$"0FFF FE00 0FFF FF00 0FFF FF80 0FFF FFC0"            /* ...... */
	$"0FFF FFE0 0FFF FFF0 0FFF FFF8 0FFF FFF8"            /* .... */
	$"0FFF FFF8 0FFF FFF8 0FFF FFF8 0FFF FFF8"            /* .... */
	$"0FFF FFF8 0FFF FFF8 0FFF FFF8 0FFF FFF8"            /* .... */
	$"0FFF FFF8 0FFF FFF8 0FFF FFF8 0FFF FFF8"            /* .... */
	$"0FFF FFF8 0FFF FFF8 0FFF FFF8 0FFF FFF8"            /* .... */
	$"0FFF FFF8 0FFF FFF8 0FFF FFF8 0FFF FFF8"            /* .... */
	$"0FFF FFF8 0FFF FFF8 0FFF FFF8 0FFF FFF8"            /* .... */
};

data 'ICN#' (130) {
	$"0FFF FE00 0800 0300 09FF C280 0A40 2240"            /* .......@"@ */
	$"0A2F 3220 0820 1210 082F 93F8 0820 1008"            /* ./2 . .../. .. */
	$"082F 1008 0820 1008 082F 9008 0820 1008"            /* ./... .../.. .. */
	$"082F 1108 0810 0908 080F FE08 0800 0008"            /* ./............ */
	$"080F FC08 0810 0208 0820 0108 082E 1D08"            /* ........ ...... */
	$"084E 1C88 084E 1C88 084E 1C88 084E 1C88"            /* .N..N..N..N. */
	$"0840 0088 0840 C088 0821 E108 0821 E108"            /* .@..@.!..!. */
	$"0810 0208 080F FC08 0800 0008 0FFF FFF8"            /* ............ */
	$"0FFF FE00 0FFF FF00 0FFF FF80 0FFF FFC0"            /* ...... */
	$"0FFF FFE0 0FFF FFF0 0FFF FFF8 0FFF FFF8"            /* .... */
	$"0FFF FFF8 0FFF FFF8 0FFF FFF8 0FFF FFF8"            /* .... */
	$"0FFF FFF8 0FFF FFF8 0FFF FFF8 0FFF FFF8"            /* .... */
	$"0FFF FFF8 0FFF FFF8 0FFF FFF8 0FFF FFF8"            /* .... */
	$"0FFF FFF8 0FFF FFF8 0FFF FFF8 0FFF FFF8"            /* .... */
	$"0FFF FFF8 0FFF FFF8 0FFF FFF8 0FFF FFF8"            /* .... */
	$"0FFF FFF8 0FFF FFF8 0FFF FFF8 0FFF FFF8"            /* .... */
};

data 'BNDL' (128) {
	$"456C 6563 0000 0001 4652 4546 0002 0000"            /* Elec....FREF.... */
	$"0080 0001 0081 0002 0083 4943 4E23 0002"            /* .......ICN#.. */
	$"0000 0080 0001 0081 0002 0082"                      /* ......... */
};

data 'FREF' (128) {
	$"4150 504C 0000 00"                                  /* APPL... */
};

data 'FREF' (129) {
	$"456C 6563 0001 00"                                  /* Elec... */
};

data 'FREF' (130) {
	$"4C4F 4720 0002 00"                                  /* LOG ... */
};

data 'FREF' (131) {
	$"4C4F 4720 0002 00"                                  /* LOG ... */
};

data 'Elec' (0) {
	$"3E45 6C65 6374 7269 6320 7665 7273 696F"            /* >Electric versio */
	$"6E20 362E 3033 2C20 436F 7079 7269 6768"            /* n 6.03, Copyrigh */
	$"7420 A920 5374 6174 6963 2046 7265 6520"            /* t  Static Free  */
	$"536F 6674 7761 7265 2C20 3230 3030 2E"              /* Software, 2000. */
};

data 'CURS' (129, "Want TTY") {
	$"EAEE 4AA8 4EEC 4488 448E 0000 FFFF 8001"            /* JNDD... */
	$"9551 8AA9 9551 8AA9 8001 9FF9 8001 FFFF"            /* QQ.. */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /*  */
	$"FFFF FFFF FFFF FFFF FFFF FFFF FFFF FFFF"            /*  */
	$"0007 0008"                                          /* .... */
};

data 'CURS' (130, "Pen", preload) {
	$"000C 001E 002F 0047 0082 0104 0208 0410"            /* ...../.G....... */
	$"0820 1040 3080 3100 7E00 7C00 F000 C000"            /* . .@01.~.|... */
	$"001E 003F 007F 00FF 01FF 03FE 07FC 0FF8"            /* ...?....... */
	$"1FF0 3FE0 7FC0 7F80 FF00 FE00 FC00 F000"            /* .?...... */
	$"000F 0000"                                          /* .... */
};

data 'CURS' (131, "Null") {
	$"1FF8 2004 2004 2004 1558 0FF0 07E0 03C0"            /* . . . ..X... */
	$"0240 0420 0810 1008 2554 3FFC 3FFC 1FF8"            /* .@. ....%T??. */
	$"3FFC 7FFE 7FFE 7FFE 3FFC 1FF8 0FF0 07E0"            /* ?...?... */
	$"07E0 0FF0 1FF8 3FFC 7FFE 7FFE 7FFE 3FFC"            /* ...?...? */
	$"0007 0008"                                          /* .... */
};

data 'CURS' (132, "Menu") {
	$"0000 0000 0020 0030 0038 003C FFFE FFFF"            /* ..... .0.8.< */
	$"FFFE 003C 0038 0030 0020 0000 0000 0000"            /* .<.8.0. ...... */
	$"0000 0060 0070 0078 007C FFFE FFFF FFFF"            /* ...`.p.x.| */
	$"FFFF FFFE 007C 0078 0070 0060 0000 0000"            /* .|.x.p.`.... */
	$"0007 000F"                                          /* .... */
};

data 'CURS' (133, "Hand", preload) {
	$"0000 01FC 0203 01C0 0200 0400 0380 0400"            /* ............. */
	$"0800 7FC0 8000 8000 7FF8 0101 0082 007C"            /* ..........| */
	$"01FC 03FF 07FF 03FF 07FF 0FFF 07FF 0FFF"            /* ........ */
	$"7FFF FFFF FFFF FFFF FFFF 7FFF 01FF 00FE"            /* .... */
	$"000B 0000"                                          /* .... */
};

data 'CURS' (134, "Tech edit", preload) {
	$"0100 0380 0540 0100 0100 3FF8 3FF8 2388"            /* ....@....??# */
	$"0380 0380 0380 0380 0380 0380 07C0 0000"            /* ......... */
	$"0380 07C0 0FE0 0FE0 7FFC 7FFC 7FFC 7FFC"            /* ........ */
	$"77DC 07C0 07C0 07C0 07C0 0FE0 0FE0 0FE0"            /* w....... */
	$"0000 0007"                                          /* .... */
};

data 'CURS' (135, "L/R arrows", preload) {
	$"0000 0000 0000 0000 1008 300C 700E FFFF"            /* ..........0.p. */
	$"FFFF 700E 300C 1008 0000 0000 0000 0000"            /* p.0........... */
	$"0000 0000 0000 0000 1008 300C 700E FFFF"            /* ..........0.p. */
	$"FFFF 700E 300C 1008 0000 0000 0000 0000"            /* p.0........... */
	$"0007 0008"                                          /* .... */
};

data 'CURS' (136, "U/D arrows", preload) {
	$"0180 03C0 07E0 0FF0 0180 0180 0180 0180"            /* ........ */
	$"0180 0180 0180 0180 0FF0 07E0 03C0 0180"            /* ........ */
	$"0180 03C0 07E0 0FF0 0180 0180 0180 0180"            /* ........ */
	$"0180 0180 0180 0180 0FF0 07E0 03C0 0180"            /* ........ */
	$"0007 0007"                                          /* .... */
};

data 'ALRT' (130, "Error") {
	$"002C 002A 00D4 014E 0082 5555"                      /* .,.*..N.UU */
};

data 'ALRT' (1129, purgeable) {
	$"0028 0014 0104 0104 0469 5555 300A"                 /* .(.......iUU0. */
};

data 'ALRT' (1130, purgeable) {
	$"0028 0014 0104 0104 046A 5555 300A"                 /* .(.......jUU0. */
};

data 'STR ' (2003) {
	$"0435 3030 31"                                       /* .5001 */
};

data 'STR ' (1128) {
	$"4C4D 6174 684C 696E 6B20 6C69 6272 6172"            /* LMathLink librar */
	$"6965 7320 A920 576F 6C66 7261 6D20 5265"            /* ies  Wolfram Re */
	$"7365 6172 6368 2C20 496E 632E 2031 3939"            /* search, Inc. 199 */
	$"302D 3139 3933 2E20 2041 6C6C 2072 6967"            /* 0-1993.  All rig */
	$"6874 7320 7265 7365 7276 6564 2E"                   /* hts reserved. */
};

data 'mstr' (102, "File") {
	$"0446 696C 65"                                       /* .File */
};

data 'mstr' (103, "Open") {
	$"0C4F 7065 6E20 4C69 6272 6172 79"                   /* .Open Library */
};

data 'icl4' (128) {
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 000F FFFF FFFF FFFF FFFF F000 0000"            /* ....... */
	$"0000 00F0 0000 0000 0000 0000 0F00 0000"            /* ............... */
	$"0000 0F00 0000 0000 0000 0000 00F0 0000"            /* ............... */
	$"0000 F000 0000 0000 0000 0000 000F 0000"            /* ............... */
	$"000F 0000 0000 0000 0000 0000 0000 F000"            /* ............... */
	$"000F 0000 0000 0000 0000 0000 0000 F000"            /* ............... */
	$"00F0 0003 3330 0000 0000 0333 3000 0F00"            /* ...30.....30... */
	$"00F0 0003 3330 0000 0000 0333 3000 0F00"            /* ...30.....30... */
	$"0F00 0003 3330 0000 0000 0333 3000 00F0"            /* ....30.....30.. */
	$"0F00 0003 3330 0000 0000 0333 3000 00F0"            /* ....30.....30.. */
	$"F000 0003 3330 0000 0000 0333 3000 000F"            /* ...30.....30... */
	$"F000 0003 3330 0000 0000 0333 3000 000F"            /* ...30.....30... */
	$"F000 0003 3330 0000 0000 0333 3000 000F"            /* ...30.....30... */
	$"F000 0003 3330 0000 0000 0333 3000 000F"            /* ...30.....30... */
	$"F000 0003 3330 0000 0000 0333 3000 000F"            /* ...30.....30... */
	$"F000 0003 3330 0000 0000 0333 3000 000F"            /* ...30.....30... */
	$"F000 0003 3330 0000 0000 0000 0000 000F"            /* ...30.......... */
	$"F000 0000 0000 0000 0000 0000 0000 000F"            /* ............... */
	$"0F00 0000 0000 0003 3000 0000 0000 00F0"            /* ........0...... */
	$"0F00 0000 0000 0033 3300 0000 0000 00F0"            /* .......33...... */
	$"00F0 0000 0000 0333 3330 0000 0000 0F00"            /* ......330...... */
	$"00F0 0000 0000 0333 3330 0000 0000 0F00"            /* ......330...... */
	$"000F 0000 0000 0333 3330 0000 0000 F000"            /* .......330..... */
	$"000F 0000 0000 0333 3330 0000 0000 F000"            /* .......330..... */
	$"0000 F000 0000 0000 0000 0000 000F 0000"            /* ............... */
	$"0000 0F00 0000 0000 0000 0000 00F0 0000"            /* ............... */
	$"0000 00F0 0000 0000 0000 0000 0F00 0000"            /* ............... */
	$"0000 000F FFFF FFFF FFFF FFFF F000 0000"            /* ....... */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
	$"0000 0000 0000 0000 0000 0000 0000 0000"            /* ................ */
};

data 'icl4' (129) {
	$"0000 FFFF FFFF FFFF FFFF FFF0 0000 0000"            /* ...... */
	$"0000 F000 0000 0000 00AA 00FF 0000 0000"            /* ............. */
	$"0000 F000 0000 0000 0AA0 00F0 F000 0000"            /* ............ */
	$"0000 F000 0000 0000 0AA0 00F0 0F00 0000"            /* ............. */
	$"0000 F000 0000 0000 0AA0 00F0 00F0 0000"            /* ............ */
	$"0000 F000 0000 0000 00AA 00F0 000F 0000"            /* ............. */
	$"0000 F000 0000 0000 000A A0FF FFFF F000"            /* .......... */
	$"0000 F000 0000 0000 000A A000 0000 F000"            /* ............. */
	$"0000 F000 0000 0000 0000 AA00 0000 F000"            /* ............. */
	$"0000 F000 0000 0000 0000 0AA0 0000 F000"            /* ............. */
	$"0000 F000 0000 0000 0000 0AA0 0000 F000"            /* ............. */
	$"0000 F000 0000 0000 0000 00AA 0000 F000"            /* ............. */
	$"0000 F000 0000 0000 0000 000A A000 F000"            /* ............. */
	$"0000 F000 0000 0000 0000 000A A000 F000"            /* ............. */
	$"0000 F000 0000 0000 0000 0000 AA00 F000"            /* ............. */
	$"0000 F000 000A A000 0000 0000 AA00 F000"            /* ............ */
	$"0000 F000 000A AA00 0000 0000 AA00 F000"            /* ............ */
	$"0000 F000 000A AAA0 0000 0000 AA00 F000"            /* ........... */
	$"0000 F022 222A AAA0 0000 00AA A000 F000"            /* ..""*..... */
	$"0000 F022 222A AAAA 000A AAAA 0000 F000"            /* ..""*..... */
	$"0000 F000 000A AAAA AAAA AA00 0000 F000"            /* ......... */
	$"0000 F000 000A AAAA AAA0 0000 0000 F000"            /* .......... */
	$"0000 F022 222A AAAA 0000 0000 0000 F000"            /* ..""*....... */
	$"0000 F022 222A AAA0 0000 0000 0000 F000"            /* ..""*....... */
	$"0000 F000 000A AAA0 0000 0000 0000 F000"            /* ............ */
	$"0000 F000 000A AA00 0000 0000 0000 F000"            /* ............. */
	$"0000 F000 000A A000 0000 0000 0000 F000"            /* ............. */
	$"0000 F000 0000 0000 0000 0000 0000 F000"            /* .............. */
	$"0000 F000 0000 0000 0000 0000 0000 F000"            /* .............. */
	$"0000 F000 0000 0000 0000 0000 0000 F000"            /* .............. */
	$"0000 F000 0000 0000 0000 0000 0000 F000"            /* .............. */
	$"0000 FFFF FFFF FFFF FFFF FFFF FFFF F000"            /* ... */
};

data 'icl4' (130) {
	$"0000 FFFF FFFF FFFF FFFF FFF0 0000 0000"            /* ...... */
	$"0000 F000 0000 0000 0000 00FF 0000 0000"            /* .............. */
	$"0000 F00B BBBB BBBB BB00 00F0 F000 0000"            /* ........ */
	$"0000 F0B0 0B00 0000 00B0 00F0 0F00 0000"            /* ............ */
	$"0000 F0B0 00B0 FFFF 00BB 00F0 00F0 0000"            /* ........ */
	$"0000 F000 00B0 0000 000B 00F0 000F 0000"            /* ............. */
	$"0000 F000 00B0 FFFF F00B 00FF FFFF F000"            /* ....... */
	$"0000 F000 00B0 0000 000B 0000 0000 F000"            /* ............. */
	$"0000 F000 00B0 FFFF 000B 0000 0000 F000"            /* ........... */
	$"0000 F000 00B0 0000 000B 0000 0000 F000"            /* ............. */
	$"0000 F000 00B0 FFFF F00B 0000 0000 F000"            /* .......... */
	$"0000 F000 00B0 0000 000B 0000 0000 F000"            /* ............. */
	$"0000 F000 00B0 FFFF 000B 000B 0000 F000"            /* ........... */
	$"0000 F000 000B 0000 0000 B00B 0000 F000"            /* ............. */
	$"0000 F000 0000 BBBB BBBB BBB0 0000 F000"            /* ........ */
	$"0000 F000 0000 0000 0000 0000 0000 F000"            /* .............. */
	$"0000 F000 0000 FFFF FFFF FF00 0000 F000"            /* ......... */
	$"0000 F000 000F 0000 0000 00F0 0000 F000"            /* ............. */
	$"0000 F000 00F0 0000 0000 000F 0000 F000"            /* ............. */
	$"0000 F000 00F0 3330 0003 330F 0000 F000"            /* ....30..3.... */
	$"0000 F000 0F00 3330 0003 3300 F000 F000"            /* .....30..3... */
	$"0000 F000 0F00 3330 0003 3300 F000 F000"            /* .....30..3... */
	$"0000 F000 0F00 3330 0003 3300 F000 F000"            /* .....30..3... */
	$"0000 F000 0F00 3330 0003 3300 F000 F000"            /* .....30..3... */
	$"0000 F000 0F00 0000 0000 0000 F000 F000"            /* ............. */
	$"0000 F000 0F00 0000 3300 0000 F000 F000"            /* .......3..... */
	$"0000 F000 00F0 0003 3330 000F 0000 F000"            /* ......30..... */
	$"0000 F000 00F0 0003 3330 000F 0000 F000"            /* ......30..... */
	$"0000 F000 000F 0000 0000 00F0 0000 F000"            /* ............. */
	$"0000 F000 0000 FFFF FFFF FF00 0000 F000"            /* ......... */
	$"0000 F000 0000 0000 0000 0000 0000 F000"            /* .............. */
	$"0000 FFFF FFFF FFFF FFFF FFFF FFFF F000"            /* ... */
};

data 'ics#' (128) {
	$"0000 1FF8 2004 4002 5C3A 9C39 9C39 9C39"            /* ... .@.\:999 */
	$"9C39 8001 8181 43C2 43C2 2004 1FF8 0000"            /* 9.CC .... */
	$"0000 1FF8 3FFC 7FFE 7FFE FFFF FFFF FFFF"            /* ...?.. */
	$"FFFF FFFF FFFF 7FFE 7FFE 3FFC 1FF8 0000"            /* ..?... */
};

data 'ics#' (129) {
	$"7FF0 4098 4114 411E 4082 4042 4022 4012"            /* .@A.A.@@B@"@. */
	$"400A 460A 5F12 47E2 5F02 4602 4002 7FFE"            /* @.F._.G_.F.@.. */
	$"7FF0 7FF8 7FFC 7FFE 7FFE 7FFE 7FFE 7FFE"            /* ........ */
	$"7FFE 7FFE 7FFE 7FFE 7FFE 7FFE 7FFE 7FFE"            /* ........ */
};

data 'ics#' (130) {
	$"7FF0 4FC8 5424 4722 4422 47A2 442A 43F2"            /* .OT$G"D"GD*C */
	$"4002 47E2 4A52 4A52 4812 4992 47E2 7FFE"            /* @.GJRJRH.IG. */
	$"7FF0 7FF8 7FFC 7FFE 7FFE 7FFE 7FFE 7FFE"            /* ........ */
	$"7FFE 7FFE 7FFE 7FFE 7FFE 7FFE 7FFE 7FFE"            /* ........ */
};

data 'ics4' (128) {
	$"0000 0000 0000 0000 000F FFFF FFFF F000"            /* ........... */
	$"00F0 0000 0000 0F00 0F00 0000 0000 00F0"            /* .............. */
	$"0F03 3300 0033 30F0 F003 3300 0033 300F"            /* ..3..30.3..30. */
	$"F003 3300 0033 300F F003 3300 0033 300F"            /* .3..30..3..30. */
	$"F003 3300 0033 300F F000 0000 0000 000F"            /* .3..30........ */
	$"F000 0003 3000 000F 0F00 0033 3300 00F0"            /* ...0......33.. */
	$"0F00 0033 3300 00F0 00F0 0000 0000 0F00"            /* ...33......... */
	$"000F FFFF FFFF F000 0000 0000 0000 0000"            /* ........... */
};

data 'ics4' (129) {
	$"0FFF FFFF FFFF 0000 0F00 0000 A00F F000"            /* ......... */
	$"0F00 000A 000F 0F00 0F00 000A 000F FFF0"            /* .............. */
	$"0F00 0000 A000 00F0 0F00 0000 0A00 00F0"            /* ............. */
	$"0F00 0000 00A0 00F0 0F00 0000 000A 00F0"            /* ............. */
	$"0F00 0000 0000 A0F0 0F00 0AA0 0000 A0F0"            /* ........... */
	$"0F02 2AAA 000A 00F0 0F00 0AAA AAA0 00F0"            /* ..*....... */
	$"0F02 2AAA 0000 00F0 0F00 0AA0 0000 00F0"            /* ..*......... */
	$"0F00 0000 0000 00F0 0FFF FFFF FFFF FFF0"            /* ........ */
};

data 'ics4' (130) {
	$"0FFF FFFF FFFF 0000 0F00 BBBB BB00 F000"            /* ....... */
	$"0F0B 0B00 00B0 0F00 0F00 0BFF 00B0 00F0"            /* ............ */
	$"0F00 0B00 00B0 00F0 0F00 0BFF F0B0 00F0"            /* .......... */
	$"0F00 0B00 00B0 B0F0 0F00 00BB BBBB 00F0"            /* ......... */
	$"0F00 0000 0000 00F0 0F00 0FFF FFF0 00F0"            /* ........... */
	$"0F00 F030 030F 00F0 0F00 F030 030F 00F0"            /* ..0.....0... */
	$"0F00 F000 000F 00F0 0F00 F003 300F 00F0"            /* .........0.. */
	$"0F00 0FFF FFF0 00F0 0FFF FFFF FFFF FFF0"            /* ..... */
};

data 'TMPL' (1128, "MLNK") {
	$"0776 6572 7369 6F6E 4457 5244 084E 6F74"            /* .versionDWRD.Not */
	$"6966 7949 4444 5752 4409 436F 6E66 6972"            /* ifyIDDWRDConfir */
	$"6D49 4444 5752 4409 5265 7175 6573 7449"            /* mIDDWRDRequestI */
	$"4444 5752 4406 5349 434E 4944 4457 5244"            /* DDWRD.SICNIDDWRD */
	$"0A55 7365 5379 7348 6561 7044 5752 4408"            /* .UseSysHeapDWRD. */
	$"4C61 756E 6368 4944 4457 5244 0D52 6571"            /* LaunchIDDWRDReq */
	$"7565 7374 4172 6756 4944 4457 5244"                 /* uestArgVIDDWRD */
};

data 'TMPL' (1129, "MLdy") {
	$"0F4E 756D 6265 7220 6F66 2069 7465 6D73"            /* .Number of items */
	$"4F43 4E54 052A 2A2A 2A2A 4C53 5443 076D"            /* OCNT.*****LSTC.m */
	$"6573 7361 6765 5053 5452 0C50 6C61 6365"            /* essagePSTR.Place */
	$"2068 6F6C 6465 7246 4259 540C 506C 6163"            /*  holderFBYT.Plac */
	$"6520 686F 6C64 6572 4157 5244 0463 6F64"            /* e holderAWRD.cod */
	$"6544 4C4E 4705 2A2A 2A2A 2A4C 5354 45"              /* eDLNG.*****LSTE */
};

data 'SICN' (1128) {
	$"030C 039C 07F8 06D8 0C30 0C30 1860 3CF0"            /* ......0.0.`< */
	$"0000 2208 2008 26CA 22AC 22AA 3AAA 0000"            /* ..". .&"":.. */
};

data 'MLNK' (1128, "MathLink") {
	$"0004 0469 046A 046B 0468 0001 046C 046D"            /* ...i.j.k.h...l.m */
};

data 'MLgl' (128) {
	$"0000 0000"                                          /* .... */
};

data 'MLdy' (128) {
	$"0012 1465 7665 7279 7468 696E 6720 6F6B"            /* ...everything ok */
	$"2073 6F20 6661 7200 0000 0000 096C 696E"            /*  so far.....lin */
	$"6B20 6469 6564 0000 0000 0001 0D62 6164"            /* k died......bad */
	$"2064 6174 6120 7265 6164 0000 0000 0002"            /*  data read...... */
	$"164D 4C47 6574 3F20 6F75 7420 6F66 2073"            /* .MLGet? out of s */
	$"6571 7565 6E63 6500 0000 0003 224D 4C50"            /* equence....."MLP */
	$"7574 4E65 7874 2829 2077 6173 2070 6173"            /* utNext() was pas */
	$"7365 6420 6120 6261 6420 746F 6B65 6E00"            /* sed a bad token. */
	$"0000 0004 164D 4C50 7574 3F20 6F75 7420"            /* .....MLPut? out  */
	$"6F66 2073 6571 7565 6E63 6500 0000 0005"            /* of sequence..... */
	$"1D4D 4C50 7574 4461 7461 2067 6976 656E"            /* .MLPutData given */
	$"2074 6F6F 206D 7563 6820 6461 7461 0000"            /*  too much data.. */
	$"0000 0006 186D 6163 6869 6E65 2069 6E74"            /* .....machine int */
	$"6567 6572 206F 7665 7266 6C6F 7700 0000"            /* eger overflow... */
	$"0007 0D6F 7574 206F 6620 6D65 6D6F 7279"            /* ..out of memory */
	$"0000 0000 0008 2366 6169 6C75 7265 2074"            /* ......#failure t */
	$"6F20 6163 6365 7074 2073 6F63 6B65 7420"            /* o accept socket  */
	$"636F 6E6E 6563 7469 6F6E 0000 0000 0009"            /* connection..... */
	$"2A61 2064 6566 6572 7265 6420 636F 6E6E"            /* *a deferred conn */
	$"6563 7469 6F6E 2069 7320 7374 696C 6C20"            /* ection is still  */
	$"756E 636F 6E6E 6563 7465 6400 0000 000A"            /* unconnected..... */
	$"2975 6E65 7870 6563 7465 6420 6F72 206D"            /* )unexpected or m */
	$"6973 7369 6E67 2063 616C 6C20 6F66 204D"            /* issing call of M */
	$"4C45 6E64 5061 636B 6574 0000 0000 0015"            /* LEndPacket...... */
	$"3C4D 4C4E 6578 7450 6163 6B65 7420 6361"            /* <MLNextPacket ca */
	$"6C6C 6564 2077 6869 6C65 2074 6865 2063"            /* lled while the c */
	$"7572 7265 6E74 2070 6163 6B65 7420 6861"            /* urrent packet ha */
	$"7320 756E 7265 6164 2064 6174 6100 0000"            /* s unread data... */
	$"0016 2B4D 4C4E 6578 7450 6163 6B65 7420"            /* ..+MLNextPacket  */
	$"7265 6164 2069 6E20 616E 2075 6E6B 6E6F"            /* read in an unkno */
	$"776E 2070 6163 6B65 7420 6865 6164 0000"            /* wn packet head.. */
	$"0000 0017 1875 6E65 7870 6563 7465 6420"            /* .....unexpected  */
	$"656E 6420 6F66 2070 6163 6B65 7400 0000"            /* end of packet... */
	$"0018 3261 2070 7574 206F 7220 6765 7420"            /* ..2a put or get  */
	$"7761 7320 6162 6F72 7465 6420 6265 666F"            /* was aborted befo */
	$"7265 2061 6666 6563 7469 6E67 2074 6865"            /* re affecting the */
	$"206C 696E 6B00 0000 0019 4274 6865 206F"            /*  link.....Bthe o */
	$"7468 6572 2073 6964 6520 636C 6F73 6564"            /* ther side closed */
	$"2074 6865 206C 696E 6B2C 2079 6F75 206D"            /*  the link, you m */
	$"6179 2073 7469 6C6C 2067 6574 2075 6E64"            /* ay still get und */
	$"656C 6976 6572 6564 2064 6174 6100 0000"            /* elivered data... */
	$"000B 0D75 6E6B 6E6F 776E 2065 7272 6F72"            /* ..unknown error */
	$"0000 FFFF FFFF"                                     /* .. */
};

data 'MLdy' (129) {
	$"0017 0A43 616C 6C50 6163 6B65 7400 0000"            /* ...CallPacket... */
	$"0007 0E45 7661 6C75 6174 6550 6163 6B65"            /* ...EvaluatePacke */
	$"7400 0000 000D 0C52 6574 7572 6E50 6163"            /* t.....ReturnPac */
	$"6B65 7400 0000 0003 0F49 6E70 7574 4E61"            /* ket......InputNa */
	$"6D65 5061 636B 6574 0000 0000 0008 0545"            /* mePacket.......E */
	$"6E74 6572 0000 0000 000E 0F45 6E74 6572"            /* nter.......Enter */
	$"5465 7874 5061 636B 6574 0000 0000 000E"            /* TextPacket...... */
	$"1545 6E74 6572 4578 7072 6573 7369 6F6E"            /* .EnterExpression */
	$"5061 636B 6574 0000 0000 000F 104F 7574"            /* Packet.......Out */
	$"7075 744E 616D 6550 6163 6B65 7400 0000"            /* putNamePacket... */
	$"0009 1052 6574 7572 6E54 6578 7450 6163"            /* ..ReturnTextPac */
	$"6B65 7400 0000 0004 1652 6574 7572 6E45"            /* ket......ReturnE */
	$"7870 7265 7373 696F 6E50 6163 6B65 7400"            /* xpressionPacket. */
	$"0000 0010 0D44 6973 706C 6179 5061 636B"            /* ....DisplayPack */
	$"6574 0000 0000 000B 1044 6973 706C 6179"            /* et.......Display */
	$"456E 6450 6163 6B65 7400 0000 000C 0D4D"            /* EndPacket.....M */
	$"6573 7361 6765 5061 636B 6574 0000 0000"            /* essagePacket.... */
	$"0005 0A54 6578 7450 6163 6B65 7400 0000"            /* ...TextPacket... */
	$"0002 0B49 6E70 7574 5061 636B 6574 0000"            /* ...InputPacket.. */
	$"0000 0001 1149 6E70 7574 5374 7269 6E67"            /* .....InputString */
	$"5061 636B 6574 0000 0000 0015 0A4D 656E"            /* Packet.......Men */
	$"7550 6163 6B65 7400 0000 0006 0C53 796E"            /* uPacket......Syn */
	$"7461 7850 6163 6B65 7400 0000 000A 0B45"            /* taxPacket......E */
	$"7272 6F72 5061 636B 6574 0000 0000 000A"            /* rrorPacket...... */
	$"0D53 7573 7065 6E64 5061 636B 6574 0000"            /* SuspendPacket.. */
	$"0000 0011 0C52 6573 756D 6550 6163 6B65"            /* .....ResumePacke */
	$"7400 0000 0012 1142 6567 696E 4469 616C"            /* t......BeginDial */
	$"6F67 5061 636B 6574 0000 0000 0013 0F45"            /* ogPacket.......E */
	$"6E64 4469 616C 6F67 5061 636B 6574 0000"            /* ndDialogPacket.. */
	$"0000 0014"                                          /* .... */
};

data 'MLcr' (1000, sysheap, locked) {
	$"4E56 0000 48E7 0118 286E 0008 266C 0046"            /* NV..H..(n..&l.F */
	$"202B 01A2 C18D 2E00 2F0C 4EBA 0012 2007"            /*  +.../.N.. . */
	$"C18D 4CEE 1880 FFF4 4E5E 2E9F 4E75 4E56"            /* L.N^.NuNV */
	$"FFF8 48E7 0018 206E 0008 2868 0046 47D0"            /* H.. n..(h.FG */
	$"2D48 FFF8 2D48 FFFC 4A6B 0010 6716 302C"            /* -H-HJk..g.0, */
	$"034C 48C0 4480 3940 034C 396B 0010 0346"            /* .LHD9@.L9k...F */
	$"6000 013A 426C 0346 206E FFFC 216B 0028"            /* `..:Bl.F n!k.( */
	$"0028 4AAB 003A 6624 2038 016A 90AC 034E"            /* .(J.:f$ 8.j.N */
	$"0C80 0000 012C 6308 7001 2740 003A 6006"            /* ....,c.p.'@.:`. */
	$"7002 2740 003A 2978 016A 034E 2F0C 4EBA"            /* p.'@.:)x.j.N/.N */
	$"0106 4A80 584F 660E 206E FFF8 7001 2140"            /* ..JXOf. np.!@ */
	$"0036 6000 00AE 7001 B0AB 003A 6634 296B"            /* .6`..p..:f4)k */
	$"0028 0026 4A6C 0344 6704 7000 6008 206C"            /* .(.&Jl.Dg.p.`. l */
	$"0352 2028 0008 206E FFFC 2140 000C 558F"            /* .R (.. n!@..U */
	$"2F2E FFFC 7001 1F00 4EBA 0248 544F 6000"            /* /.p...N.HTO`. */
	$"00AC 7002 B0AB 003A 665E 7003 B06C 034C"            /* .p..:f^p.l.L */
	$"670C 206E FFF8 7002 2140 0036 6054 2F0C"            /* g. np.!@.6`T/. */
	$"4EBA 00E6 4A80 584F 660C 206E FFF8 7003"            /* N.JXOf. np. */
	$"2140 0036 603C 296B 0028 00D6 4A6C 0344"            /* !@.6`<)k.(.Jl.D */
	$"6704 7000 6008 206C 0352 2028 000C 206E"            /* g.p.`. l.R (.. n */
	$"FFFC 2140 000C 558F 2F2E FFFC 7001 1F00"            /* !@..U/.p... */
	$"4EBA 01E0 544F 6044 206E FFF8 7004 2140"            /* N.TO`D np.!@ */
	$"0036 397C 0001 0346 4A6C 0344 6704 7000"            /* .69|...FJl.Dg.p. */
	$"6008 206C 0352 2028 0004 206E FFF8 2140"            /* `. l.R (.. n!@ */
	$"000C 206E FFF8 216B 0028 0028 558F 2F2E"            /* .. n!k.(.(U/. */
	$"FFF8 7001 1F00 4EBA 01AE 544F 4CEE 1800"            /* p...N.TOL.. */
	$"FFF0 4E5E 4E75 4E56 0000 48E7 1008 286E"            /* N^NuNV..H..(n */
	$"0008 7600 7002 B06C 01D8 6618 2F03 487A"            /* ..v.p.l.f./.Hz */
	$"0024 486C 01DA 4EBA 00D6 508F 261F 4A40"            /* .$Hl.N.P&.J@ */
	$"6602 7601 4883 48C3 2003 4CEE 1008 FFF8"            /* f.v.HH .L.. */
	$"4E5E 4E75 1259 616E 6720 4D61 7468 4C69"            /* N^Nu.Yang MathLi */
	$"6E6B 2056 312E 3000 4E56 0000 48E7 1008"            /* nk V1.0.NV..H.. */
	$"286E 0008 7600 2F03 7000 102C 01B6 2F00"            /* (n..v./.p..,./. */
	$"41EC 01B6 5248 2F08 486C 0264 4EBA 00E2"            /* A.RH/.Hl.dN. */
	$"4FEF 000C 261F 4A80 6664 7001 B06C 01FC"            /* O..&.Jfdp.l. */
	$"6648 2F03 7000 102C 01FE 2F00 41EC 01FE"            /* fH/.p..,./.A. */
	$"5248 2F08 486C 0288 4EBA 00B6 4FEF 000C"            /* RH/.Hl.N.O.. */
	$"261F 4A80 6624 2F03 7000 102C 0242 2F00"            /* &.Jf$/.p..,.B/. */
	$"41EC 0242 5248 2F08 486C 02AC 4EBA 0092"            /* A.BRH/.Hl.N. */
	$"4FEF 000C 261F 4A80 6712 4A6C 01FC 660E"            /* O..&.Jg.Jl.f. */
	$"4A2C 0288 6608 4A2C 02AC 6602 7601 4883"            /* J,.f.J,.f.v.H */
	$"48C3 2003 4CEE 1008 FFF8 4E5E 4E75 4E56"            /* H .L..N^NuNV */
	$"0000 48E7 1318 266E 000C 286E 0008 1014"            /* ..H..&n..(n.... */
	$"B013 52C3 4403 6704 1013 6002 1014 7C00"            /* .RD.g...`...|. */
	$"1C00 7E01 6004 2007 5287 BC87 6D0A 1034"            /* ..~.`. .Rm..4 */
	$"7800 B033 7800 67EE BC87 6C0C 7000 1014"            /* x.3x.gl.p... */
	$"7200 1213 9041 600E 7000 1034 7800 7200"            /* r...A`.p..4x.r. */
	$"1233 7800 9041 4CEE 18C8 FFEC 4E5E 4E75"            /* .3x.AL.N^Nu */
	$"4CEF 0300 0004 222F 000C 7000 600A 1018"            /* L...."/..p.`... */
	$"B019 660C 4A00 6704 5381 64F2 7000 4E75"            /* .f.J.g.Sdp.Nu */
	$"7200 1221 9081 4E75 8773 7472 6E63 6D70"            /* r..!Nustrncmp */
	$"0000 7004 225F 121F 205F 6604 A0DD 6002"            /* ..p."_.. _f.`. */
	$"A4DD 3E80 4ED1 7005 225F 121F 205F 6604"            /* >Np."_.. _f. */
	$"A0DD 6002 A4DD 3E80 4ED1"                           /* `.>N */
};

data 'MLcr' (1001, sysheap, locked) {
	$"4E56 0000 48E7 0118 286E 0008 266C 0046"            /* NV..H..(n..&l.F */
	$"202B 01A2 C18D 2E00 2F0C 4EBA 0012 2007"            /*  +.../.N.. . */
	$"C18D 4CEE 1880 FFF4 4E5E 2E9F 4E75 4E56"            /* L.N^.NuNV */
	$"FFFC 48E7 0018 206E 0008 2868 0046 2D48"            /* H.. n..(h.F-H */
	$"FFFC 47D0 4A68 0010 6718 302C 034C 48C0"            /* GJh..g.0,.LH */
	$"4480 3940 034C 206E FFFC 3968 0010 0346"            /* D9@.L n9h...F */
	$"6044 426C 0346 4A6C 0344 6704 7000 6006"            /* `DBl.FJl.Dg.p.`. */
	$"206C 0352 2010 2740 000C 3754 0026 422B"            /*  l.R .'@..7T.&B+ */
	$"002D 41EC 01B4 2748 002E 41EC 01FC 2748"            /* .-A.'H..A.'H */
	$"0032 7000 2740 0036 558F 2F0B 7001 1F00"            /* .2p.'@.6U/.p... */
	$"4EBA 000E 544F 4CEE 1800 FFF4 4E5E 4E75"            /* N..TOL..N^Nu */
	$"7003 225F 121F 205F 6604 A0DD 6002 A4DD"            /* p."_.. _f.`. */
	$"3E80 4ED1"                                          /* >N */
};

data 'MLcr' (1002, sysheap, locked) {
	$"4E56 0000 48E7 0118 286E 0008 266C 0046"            /* NV..H..(n..&l.F */
	$"202B 01A2 C18D 2E00 2F0C 4EBA 0012 2007"            /*  +.../.N.. . */
	$"C18D 4CEE 1880 FFF4 4E5E 2E9F 4E75 4E56"            /* L.N^.NuNV */
	$"FFFC 48E7 0018 206E 0008 2868 0046 2D48"            /* H.. n..(h.F-H */
	$"FFFC 47D0 4A68 0010 6718 302C 034C 48C0"            /* GJh..g.0,.LH */
	$"4480 3940 034C 206E FFFC 3968 0010 0346"            /* D9@.L n9h...F */
	$"6050 426C 0346 397C 0003 034C 2F0C 4EBA"            /* `PBl.F9|...L/.N */
	$"004C 4A6C 0344 6704 7000 6006 206C 0352"            /* .LJl.Dg.p.`. l.R */
	$"2010 2740 000C 3754 0026 422B 002D 41EC"            /*  .'@..7T.&B+.-A */
	$"01B4 2748 002E 41EC 01FC 2748 0032 7000"            /* .'H..A.'H.2p. */
	$"2740 0036 558F 2F0B 7001 1F00 4EBA 00EA"            /* '@.6U/.p...N. */
	$"5C4F 4CEE 1800 FFF4 4E5E 4E75 4E56 0000"            /* \OL..N^NuNV.. */
	$"2F0C 286E 0008 7000 102C 01B6 2F00 41EC"            /* /.(n..p..,./.A */
	$"01B6 5248 2F08 486C 0264 4EBA 007E 7000"            /* .RH/.Hl.dN.~p. */
	$"102C 01B6 41EC 0264 4230 0000 7001 B06C"            /* .,.A.dB0..p.l */
	$"01FC 4FEF 000C 6652 7000 102C 01FE 2F00"            /* .O..fRp..,./. */
	$"41EC 01FE 5248 2F08 486C 0288 4EBA 004C"            /* A.RH/.Hl.N.L */
	$"7000 102C 01FE 41EC 0288 4230 0000 7000"            /* p..,.A.B0..p. */
	$"102C 0242 2F00 41EC 0242 5248 2F08 486C"            /* .,.B/.A.BRH/.Hl */
	$"02AC 4EBA 0026 7000 102C 0242 41EC 02AC"            /* .N.&p..,.BA. */
	$"4230 0000 4FEF 0018 6008 422C 0288 422C"            /* B0..O..`.B,.B, */
	$"02AC 286E FFFC 4E5E 4E75 4CEF 0300 0004"            /* .(nN^NuL.... */
	$"222F 000C 7001 6004 4841 10D9 57C9 FFFC"            /* "/..p.`.HA.W */
	$"670C 4841 51C9 FFF2 600E 4841 4218 51C9"            /* g.HAQ`.HAB.Q */
	$"FFFC 4841 51C9 FFF4 202F 0004 4E75 8773"            /* HAQ /..Nus */
	$"7472 6E63 7079 0000 7003 225F 121F 205F"            /* trncpy..p."_.. _ */
	$"6604 A0DD 6002 A4DD 3E80 4ED1"                      /* f.`.>N */
};

data 'MLcr' (1003, sysheap, locked) {
	$"4E56 0000 48E7 0118 286E 0008 266C 0046"            /* NV..H..(n..&l.F */
	$"202B 01A2 C18D 2E00 2F0C 4EBA 0012 2007"            /*  +.../.N.. . */
	$"C18D 4CEE 1880 FFF4 4E5E 2E9F 4E75 4E56"            /* L.N^.NuNV */
	$"0000 48E7 0018 206E 0008 2868 0046 47D0"            /* ..H.. n..(h.FG */
	$"4A6B 0010 6714 302C 034C 48C0 4480 3940"            /* Jk..g.0,.LHD9@ */
	$"034C 396B 0010 0346 607E 426C 0346 397C"            /* .L9k...F`~Bl.F9| */
	$"0004 034C 47EC 00DA 276C 00D6 0028 206C"            /* ...LG.'l..( l */
	$"0352 2768 0010 000C 486B 002C 486B 0034"            /* .R'h....Hk.,Hk.4 */
	$"486C 016E 4EBA 005C 558F 2F0B 7001 1F00"            /* Hl.nN.\U/.p... */
	$"4EBA 009C 47EC 002A 276C 0026 0028 206C"            /* N.G.*'l.&.( l */
	$"0352 2768 0018 000C 426C 00D4 486B 002C"            /* .R'h....Bl.Hk., */
	$"486B 0034 486C 00BE 4EBA 0028 558F 2F0B"            /* Hk.4Hl.N.(U/. */
	$"7001 1F00 4EBA 0068 558F 486C 02D8 3F3C"            /* p...N.hUHl.?< */
	$"003C A88F 4FEF 001E 4CEE 1800 FFF8 4E5E"            /* .<O..L..N^ */
	$"4E75 4E56 0000 48E7 0018 266E 000C 286E"            /* NuNV..H..&n..(n */
	$"0008 4A6C 0010 6704 7000 6028 26AC 000C"            /* ..Jl..g.p.`(&.. */
	$"202C 0008 B093 630E 202C 0008 9093 206E"            /*  ,..c. ,.. n */
	$"0010 2080 600C 202C 0004 9093 206E 0010"            /* .. `. ,.. n.. */
	$"2080 7001 4CEE 1800 FFF8 4E5E 4E75 7007"            /*  p.L..N^Nup. */
	$"225F 121F 205F 6604 A0DD 6002 A4DD 3E80"            /* "_.. _f.`.> */
	$"4ED1"                                               /* N */
};

data 'MLcr' (1004, sysheap, locked) {
	$"4E56 0000 48E7 0118 286E 0008 266C 0046"            /* NV..H..(n..&l.F */
	$"202B 01A2 C18D 2E00 2F0C 4EBA 0012 2007"            /*  +.../.N.. . */
	$"C18D 4CEE 1880 FFF4 4E5E 2E9F 4E75 4E56"            /* L.N^.NuNV */
	$"FFF8 48E7 0018 206E 0008 2868 0046 47D0"            /* H.. n..(h.FG */
	$"4A6B 0010 670A 396B 0010 0346 6000 00B6"            /* Jk..g.9k...F`.. */
	$"2F2B 0030 486C 016E 4EBA 0186 4AAC 019A"            /* /+.0Hl.nN.J. */
	$"504F 673E 486E FFFC 486E FFF8 486C 016E"            /* POg>HnHnHl.n */
	$"4EBA 009C 7208 B280 4FEF 000C 6E24 206E"            /* N.r.O..n$ n */
	$"FFF8 2F28 0004 2F10 2F2C 019E 206C 019A"            /* /(.././,. l. */
	$"4E90 7008 2F00 486C 016E 4EBA 00CC 4FEF"            /* Np./.Hl.nN.O */
	$"0014 486B 002C 486B 0034 486C 016E 4EBA"            /* ..Hk.,Hk.4Hl.nN */
	$"00E4 4A80 4FEF 000C 6710 558F 2F0B 7001"            /* .JO..g.U/.p. */
	$"1F00 4EBA 0154 544F 602C 7008 2F00 486C"            /* ..N.TTO`,p./.Hl */
	$"016E 4EBA 0094 486B 002C 486B 0034 486C"            /* .nN.Hk.,Hk.4Hl */
	$"016E 4EBA 00B0 558F 2F0B 7001 1F00 4EBA"            /* .nN.U/.p...N */
	$"0128 4FEF 0016 558F 486C 02D8 3F3C 003C"            /* .(O..UHl.?<.< */
	$"A88F 544F 4CEE 1800 FFF0 4E5E 4E75 4E56"            /* TOL..N^NuNV */
	$"0000 48E7 0018 286E 0008 266C 000C B7EC"            /* ..H..(n..&l.. */
	$"0008 660A 4A6C 0010 6604 7000 6030 206E"            /* ..f.Jl..f.p.`0 n */
	$"000C 20AC 0008 B7EC 0008 630E 200B 90AC"            /* .. ....c. . */
	$"0008 206E 0010 2080 600E 202C 0004 90AC"            /* .. n.. `. ,.. */
	$"0008 206E 0010 2080 206E 0010 2010 4CEE"            /* .. n..  n.. .L */
	$"1800 FFF8 4E5E 4E75 4E56 0000 2F0C 286E"            /* ..N^NuNV../.(n */
	$"0008 202E 000C D1AC 0008 202C 0008 B0AC"            /* .. ...Ѭ.. ,.. */
	$"0004 6604 2954 0008 426C 0010 286E FFFC"            /* ..f.)T..Bl..(n */
	$"4E5E 4E75 4E56 0000 48E7 0018 266E 000C"            /* N^NuNV..H..&n.. */
	$"286E 0008 4A6C 0010 6704 7000 6028 26AC"            /* (n..Jl..g.p.`(& */
	$"000C 202C 0008 B093 630E 202C 0008 9093"            /* .. ,..c. ,.. */
	$"206E 0010 2080 600C 202C 0004 9093 206E"            /*  n.. `. ,.. n */
	$"0010 2080 7001 4CEE 1800 FFF8 4E5E 4E75"            /* .. p.L..N^Nu */
	$"4E56 0000 2F0C 286E 0008 202E 000C D1AC"            /* NV../.(n.. ...Ѭ */
	$"000C 202C 000C B0AC 0004 6604 2954 000C"            /* .. ,....f.)T.. */
	$"202C 000C B0AC 0008 6606 397C 0001 0010"            /*  ,....f.9|.... */
	$"286E FFFC 4E5E 4E75 7007 225F 121F 205F"            /* (nN^Nup."_.. _ */
	$"6604 A0DD 6002 A4DD 3E80 4ED1"                      /* f.`.>N */
};

data 'MLcr' (1005, sysheap, locked) {
	$"4E56 0000 48E7 0118 286E 0008 266C 0046"            /* NV..H..(n..&l.F */
	$"202B 01A2 C18D 2E00 2F0C 4EBA 0012 2007"            /*  +.../.N.. . */
	$"C18D 4CEE 1880 FFF4 4E5E 2E9F 4E75 4E56"            /* L.N^.NuNV */
	$"0000 48E7 0018 206E 0008 2668 0046 49D0"            /* ..H.. n..&h.FI */
	$"4A6C 0010 6708 376C 0010 0346 6034 202C"            /* Jl..g.7l...F`4 , */
	$"0030 B0AB 0196 6C2A 202C 0030 91AB 0196"            /* .0.l* ,.0. */
	$"41EB 018E 5048 91EB 0196 2948 0034 296B"            /* A.PH.)H.4)k */
	$"0196 002C 558F 2F0C 7001 1F00 4EBA 000E"            /* ..,U/.p...N.. */
	$"544F 4CEE 1800 FFF8 4E5E 4E75 7006 225F"            /* TOL..N^Nup."_ */
	$"121F 205F 6604 A0DD 6002 A4DD 3E80 4ED1"            /* .. _f.`.>N */
};

data 'MLcr' (1006, sysheap, locked) {
	$"4E56 0000 48E7 0118 286E 0008 266C 0046"            /* NV..H..(n..&l.F */
	$"202B 01A2 C18D 2E00 2F0C 4EBA 0012 2007"            /*  +.../.N.. . */
	$"C18D 4CEE 1880 FFF4 4E5E 2E9F 4E75 4E56"            /* L.N^.NuNV */
	$"0000 48E7 0018 206E 0008 2668 0046 49D0"            /* ..H.. n..&h.FI */
	$"4A6C 0010 6708 376C 0010 0346 6048 2F2C"            /* Jl..g.7l...F`H/, */
	$"0030 486B 00BE 4EBA 0094 486C 002C 486C"            /* .0Hk.N.Hl.,Hl */
	$"0034 486B 00BE 4EBA 0038 4A80 4FEF 0014"            /* .4Hk.N.8JO.. */
	$"6710 558F 2F0C 7001 1F00 4EBA 00A8 544F"            /* g.U/.p...N.TO */
	$"6006 377C 0001 00D4 558F 486B 02D8 3F3C"            /* `.7|...UHk.?< */
	$"003C A88F 544F 4CEE 1800 FFF8 4E5E 4E75"            /* .<TOL..N^Nu */
	$"4E56 0000 48E7 0018 266E 000C 286E 0008"            /* NV..H..&n..(n.. */
	$"4A6C 0010 6704 7000 6028 26AC 000C 202C"            /* Jl..g.p.`(&.. , */
	$"0008 B093 630E 202C 0008 9093 206E 0010"            /* ..c. ,.. n.. */
	$"2080 600C 202C 0004 9093 206E 0010 2080"            /*  `. ,.. n..  */
	$"7001 4CEE 1800 FFF8 4E5E 4E75 4E56 0000"            /* p.L..N^NuNV.. */
	$"2F0C 286E 0008 202E 000C D1AC 000C 202C"            /* /.(n.. ...Ѭ.. , */
	$"000C B0AC 0004 6604 2954 000C 202C 000C"            /* ....f.)T.. ,.. */
	$"B0AC 0008 6606 397C 0001 0010 286E FFFC"            /* ..f.9|....(n */
	$"4E5E 4E75 7007 225F 121F 205F 6604 A0DD"            /* N^Nup."_.. _f. */
	$"6002 A4DD 3E80 4ED1"                                /* `.>N */
};

data 'MLcr' (1007, sysheap, locked) {
	$"4E56 0000 48E7 0118 286E 0008 266C 0046"            /* NV..H..(n..&l.F */
	$"202B 01A2 C18D 2E00 2F0C 4EBA 0012 2007"            /*  +.../.N.. . */
	$"C18D 4CEE 1880 FFF4 4E5E 2E9F 4E75 4E56"            /* L.N^.NuNV */
	$"0000 48E7 0018 206E 0008 2668 0046 49D0"            /* ..H.. n..&h.FI */
	$"4A6C 0010 6708 376C 0010 0346 600E 558F"            /* Jl..g.7l...F`.U */
	$"486B 02D8 3F3C 003C A88F 544F 4CEE 1800"            /* Hk.?<.<TOL.. */
	$"FFF8 4E5E 4E75"                                     /* N^Nu */
};

data 'STR#' (1132, purgeable) {
	$"0004 A654 6869 7320 6C69 7374 2073 686F"            /* ..This list sho */
	$"7773 2074 6865 2063 6F6E 7465 6E74 7320"            /* ws the contents  */
	$"6F66 2074 6865 2069 7465 6D20 6E61 6D65"            /* of the item name */
	$"6420 6162 6F76 652E 2020 446F 7562 6C65"            /* d above.  Double */
	$"2D63 6C69 636B 2061 2066 6F6C 6465 7220"            /* -click a folder  */
	$"6F72 2064 6973 6B20 746F 2073 6565 2069"            /* or disk to see i */
	$"7473 2063 6F6E 7465 6E74 7320 696E 2074"            /* ts contents in t */
	$"6869 7320 7769 6E64 6F77 2E20 446F 7562"            /* his window. Doub */
	$"6C65 2D63 6C69 636B 2061 204D 6174 684C"            /* le-click a MathL */
	$"696E 6B20 7072 6F67 7261 6D20 746F 206C"            /* ink program to l */
	$"6175 6E63 6820 6974 2E3B 546F 206C 6175"            /* aunch it.;To lau */
	$"6E63 6820 7468 6520 7365 6C65 6374 6564"            /* nch the selected */
	$"204D 6174 684C 696E 6B20 7072 6F67 7261"            /*  MathLink progra */
	$"6D2C 2063 6C69 636B 2074 6869 7320 6275"            /* m, click this bu */
	$"7474 6F6E 2EDA 546F 2073 6565 2074 6865"            /* tton.To see the */
	$"2063 6F6E 7465 6E74 7320 6F66 2074 6865"            /*  contents of the */
	$"2073 656C 6563 7465 6420 6469 736B 206F"            /*  selected disk o */
	$"7220 666F 6C64 6572 2C20 6F72 2074 6F20"            /* r folder, or to  */
	$"6C61 756E 6368 2074 6865 2073 656C 6563"            /* launch the selec */
	$"7465 6420 4D61 7468 4C69 6E6B 2070 726F"            /* ted MathLink pro */
	$"6772 616D 2C20 636C 6963 6B20 7468 6973"            /* gram, click this */
	$"2062 7574 746F 6E2E 2020 5468 6520 6275"            /*  button.  The bu */
	$"7474 6F6E 2069 7320 6E6F 7420 6176 6169"            /* tton is not avai */
	$"6C61 626C 6520 6265 6361 7573 6520 6E6F"            /* lable because no */
	$"7468 696E 6720 6973 2073 656C 6563 7465"            /* thing is selecte */
	$"642C 206F 7220 6265 6361 7573 6520 796F"            /* d, or because yo */
	$"7520 6361 6E6E 6F74 206F 7065 6E20 7468"            /* u cannot open th */
	$"6520 7365 6C65 6374 6564 2069 7465 6D2E"            /* e selected item. */
	$"5054 6F20 636C 6F73 6520 7468 6520 6469"            /* PTo close the di */
	$"616C 6F67 2062 6F78 2077 6974 686F 7574"            /* alog box without */
	$"206C 6175 6E63 6869 6E67 2061 204D 6174"            /*  launching a Mat */
	$"684C 696E 6B20 7072 6F67 7261 6D2C 2063"            /* hLink program, c */
	$"6C69 636B 2074 6869 7320 6275 7474 6F6E"            /* lick this button */
	$"2E"                                                 /* . */
};

data 'hdlg' (136, purgeable) {
	$"0002 0000 0000 0000 0000 0000 0007 0004"            /* ................ */
	$"0100 0020 0003 0000 0000 0000 0000 0000"            /* ... ............ */
	$"0000 E863 0008 E863 0009 E863 0016 E863"            /* ..c..c.c..c */
	$"0017 0020 0003 0000 0000 0000 0000 0000"            /* ... ............ */
	$"0000 E863 000A E863 0000 E863 0000 E863"            /* ..c..c..c..c */
	$"0000 0004 0100 0020 0003 000C 0050 0000"            /* ....... .....P.. */
	$"0000 0000 0000 E863 0003 E863 0000 E863"            /* ......c..c..c */
	$"0000 E863 0000 0020 0003 0000 0000 0000"            /* ..c... ........ */
	$"0000 0000 0000 E863 0004 E863 0005 E863"            /* ......c..c..c */
	$"0000 E863 0000 0020 0003 0000 0000 0000"            /* ..c... ........ */
	$"0000 0000 0000 E863 0006 E863 0007 E863"            /* ......c..c..c */
	$"0000 E863 0000 0020 0003 0000 0000 0000"            /* ..c... ........ */
	$"0000 0000 0000 E863 0002 E863 0000 E863"            /* ......c..c..c */
	$"0000 E863 0000"                                     /* ..c.. */
};

data 'dctb' (136, purgeable) {
	$"0000 0000 0000 FFFF"                                /* ...... */
};

